# vpx-rtp-py

[![PyPI version](https://badge.fury.io/py/vpx-rtp-py.svg)](https://badge.fury.io/py/vpx-rtp-py)

python library for encoding/decoding video rtp streams using `libvpx`, loosly forked from `aiortc`.

narrowly constructed for the use cases of [Tutor Intelligence](http://tutorintelligence.com/), but feel free to post an issue or PR if relevant to you.